Index: trunk/src/org/openstreetmap/josm/data/validation/tests/TurnrestrictionTest.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/TurnrestrictionTest.java	(revision 15018)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/TurnrestrictionTest.java	(revision 15019)
@@ -18,5 +18,5 @@
 
 /**
  * Checks if turnrestrictions are valid
  * @since 3669
  */
@@ -53,5 +53,5 @@
      */
     public TurnrestrictionTest() {
-        super(tr("Turnrestrictions"), tr("This test checks if turnrestrictions are valid."));
+        super(tr("Turn restrictions"), tr("This test checks if turn restrictions are valid."));
     }
 
@@ -63,5 +63,5 @@
         if (!r.hasTag("restriction", SUPPORTED_RESTRICTIONS)) {
             errors.add(TestError.builder(this, Severity.ERROR, UNKNOWN_RESTRICTION)
-                    .message(tr("Unknown turnrestriction"))
+                    .message(tr("Unknown turn restriction"))
                     .primitives(r)
                     .build());
@@ -116,5 +116,5 @@
                 default:
                     errors.add(TestError.builder(this, Severity.WARNING, UNEXPECTED_ROLE)
-                            .message(tr("Unexpected role ''{0}'' in turnrestriction", m.getRole()))
+                            .message(tr("Unexpected role ''{0}'' in turn restriction", m.getRole()))
                             .primitives(l)
                             .highlight(m.getMember())
@@ -135,5 +135,5 @@
                 } else {
                     errors.add(TestError.builder(this, Severity.WARNING, UNEXPECTED_ROLE)
-                            .message(tr("Unexpected role ''{0}'' in turnrestriction", m.getRole()))
+                            .message(tr("Unexpected role ''{0}'' in turn restriction", m.getRole()))
                             .primitives(l)
                             .highlight(m.getMember())
@@ -142,5 +142,5 @@
             } else {
                 errors.add(TestError.builder(this, Severity.WARNING, UNEXPECTED_TYPE)
-                        .message(tr("Unexpected member type in turnrestriction"))
+                        .message(tr("Unexpected member type in turn restriction"))
                         .primitives(l)
                         .highlight(m.getMember())
@@ -225,5 +225,5 @@
             if (isFullOneway(toWay) && viaNode.equals(toWay.lastNode(true))) {
                 errors.add(TestError.builder(this, Severity.WARNING, SUPERFLUOUS)
-                        .message(tr("Superfluous turnrestriction as \"to\" way is oneway"))
+                        .message(tr("Superfluous turn restriction as \"to\" way is oneway"))
                         .primitives(r)
                         .highlight(toWay)
@@ -233,5 +233,5 @@
             if (isFullOneway(fromWay) && viaNode.equals(fromWay.firstNode(true))) {
                 errors.add(TestError.builder(this, Severity.WARNING, SUPERFLUOUS)
-                        .message(tr("Superfluous turnrestriction as \"from\" way is oneway"))
+                        .message(tr("Superfluous turn restriction as \"from\" way is oneway"))
                         .primitives(r)
                         .highlight(fromWay)
@@ -248,5 +248,5 @@
             if (isFullOneway(toWay) && ((Way) via.get(via.size() - 1)).isFirstLastNode(toWay.lastNode(true))) {
                 errors.add(TestError.builder(this, Severity.WARNING, SUPERFLUOUS)
-                        .message(tr("Superfluous turnrestriction as \"to\" way is oneway"))
+                        .message(tr("Superfluous turn restriction as \"to\" way is oneway"))
                         .primitives(r)
                         .highlight(toWay)
@@ -256,5 +256,5 @@
             if (isFullOneway(fromWay) && ((Way) via.get(0)).isFirstLastNode(fromWay.firstNode(true))) {
                 errors.add(TestError.builder(this, Severity.WARNING, SUPERFLUOUS)
-                        .message(tr("Superfluous turnrestriction as \"from\" way is oneway"))
+                        .message(tr("Superfluous turn restriction as \"from\" way is oneway"))
                         .primitives(r)
                         .highlight(fromWay)
@@ -18,5 +18,5 @@
 
 /**
- * Checks if turnrestrictions are valid
+ * Checks if turn restrictions are valid
  * @since 3669
  */
